#
# spec file for package kreport
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 4

Name:           kreport
Version:        3.1.0
Release:        lp150.1.19
Summary:        Framework for creation and generation of reports
License:        LGPL-2.0
Group:          Productivity/Office/Other
Url:            http://community.kde.org/KReport
Source0:        https://download.kde.org/stable/%{name}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kconfig-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kguiaddons-devel
BuildRequires:  kproperty-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  marble-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  python-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-lang

%description
A framework for creation and generation of reports in multiple formats

%package -n libKReport3-%{sover}
Summary:        The library for the Report Creation and generation Framework
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libKReport3-%{sover}
The main library for the Report creation and generation framework

%package devel
Summary:        Development package for KReport
Group:          Development/Libraries/KDE
Requires:       kproperty-devel
Requires:       libKReport3-%{sover} = %{version}

%description devel
Development package for the Report Creation and Generation framework

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%make_jobs

%install
  %kf5_makeinstall -C build
  %find_lang %{name} %{name}.lang --all-name --with-qt

%post -n libKReport3-%{sover} -p /sbin/ldconfig
%postun -n libKReport3-%{sover} -p /sbin/ldconfig

%files -n libKReport3-%{sover}
%defattr(-,root,root,-)
%doc COPYING.LIB
%{_libdir}/libKReport3.so.*

%files
%defattr(-,root,root,-)
%{_datadir}/kreport3/
%{_kf5_servicetypesdir}/kreport_elementplugin.desktop
%{_kf5_plugindir}/kreport3/

%files devel
%defattr(-,root,root,-)
%doc COPYING*
%{_includedir}/KReport3/
%{_libdir}/cmake/KReport3/
%{_libdir}/libKReport3.so
%{_libdir}/pkgconfig/KReport3.pc
%{_kf5_mkspecsdir}/qt_KReport3.pri

%files lang -f %{name}.lang
%defattr(-,root,root,-)

%changelog
* Tue Mar 20 2018 wbauer@tmo.at
- Update to 3.1.0:
  * General
    + Bump soname for the libraries to separate from incompatible
    3.0.x versions
    + Add Python 3 support for the buildsystem
  * New features
    + Add support for custom page width/height
    + Add more page sizes
  * API changes
    + see https://community.kde.org/Kexi/Releases/3.1.0_Changes for
    details
  * Bug fixes
    + Fix rendering asynchronously rendered elements such as maps and
    web boxes
    + Stability fixes from Coverity tests
    + Fix build warnings and clear up init() code for items
    + Fix crash in SortedField when copy-constructing
    + Fix usage of QPageLayout by calling the non default constructor
    + Port QRegExp to QRegularExpression
    + Remove unnescessary strings for translation
    + Linestyle width > weight
    + Fix initialization of report elements created by user, e.g.
    barcodes had invalid default settings
    + Fix field type not updating report dirty state
    + Improve detection of scripting in reports
    + Set the default interpreter to Javascript if it is empty
    + Fix interpreter if empty
    + Add missing features from 2.9
    + Always save the interpreter as javascript if empty
    + Fix broken logic related to looping over report elements
    + Fix recursion crash when item is smaller than scene
    + Change X-KReport-Priority field in .desktop files to
    X-KReport-PluginInfo-Priority
    + Fix horizontal alignment for barcode scripting and use
    alignment enum
    + Make KReport build and kreportexample run also when
    KREPORT_SCRIPTING is OFF
    + Fix crash when showing first-page section
    + Fix crash when pasting line element
    + Improve initialization of properties in Report Designer
    + Use suffix option from the new KProperty instead of units;
    implement units locally in KReport
  * Docs and examples
    + Enable creation of API docs QCH file during the build
    + Add and improve user scripting API docs from 2.9
    + Add brief docs for exported classes
- Add separate lang subpackage that contains the new translations
* Wed Feb 28 2018 wbauer@tmo.at
- Add python-base build requirement to fix build in Leap 15
* Sat Aug 12 2017 wbauer@tmo.at
- Update to 3.0.2:
  * General
  - New: Port the Group dialog widget from Qt 4.
  - Fix loading of pen style data (kde#378561)
  - Improvements of handling pen width. Set step value of 1.0.
  - Improve accuracy of line weight property.
  - Fix initialization of report elements created by user, e.g.
    barcodes had invalid default settings
  - Fix possible crashes while switching from design view to
    preview
  - Improve detection of scripting. Always save the script,
    regardless of whether or not the object script is empty, this
    way and default to the original script, unless the object
    script has been changed so the original interpreter should be
    saved properly.
  - Set the default interpreter to JavaScript if empty
  * Buildsystem
  - Make sure KProperty* libs are not newer than 3.0.x
  * Tests
  - Fix HeadersTest for paths containing spaces
* Tue Apr  4 2017 wbauer@tmo.at
- Update to 3.0.1:
  * General
  - Add 24x24 icons, useful on classic Windows
  - Try to locate rcc files in PATH subdirs too, useful for
    running apps from the build dir, without installing
  - Fix async rendering of map item (Review #3028)
  - Add all PROJECT_STABLE* and KREPORT_TESTING_EXPORT constants
  - Synchronize plugin versions with KReport version: 3.0
  - Check for plugin versions and duplicates in the plugin
    manager
  - Fix uninitialized variables in KReportItemMaps()
  - Fix uninitialized variables in KReportItemText(), OROCheck(),
    KReportPluginMetaData::Private()
  - Add checks for nullptrs in KReportItemWeb, KReportItemMaps,
    KReportItemChart
  - Add missing initializations in KReportSectionData
  - Add missing initializations in KReportItemBarcode
  - Add BoundedTextItem init, make the type qreal [0..1] for
    consistency with Qt
  - Keep apps in the same bin dir so resources that are kept
    relative to this dir can be found without installing
  * Buildsystem
  - macro kreport_add_icons_rcc_file: generate rcc icons in the
    builddir/bin/data/icons/ dir so it can be used within the
    builddir
  - Use ecm_install_po_files_as_qm macro for Qt Translation
    catalogs
  - Fix finding KReport config - use
    ecm_configure_package_config_file macro
- Drop unused KF5I18n BuildRequires
* Wed Jan 11 2017 jengelh@inai.de
- RPM group fix
* Sun Jan  8 2017 tittiatcoke@gmail.com
- Initial package based on version 3.0.0
